PyEmir Documentation
====================

Welcome. This is the Documentation for PyEmir (version |version|), 

EMIR is a **wide-field, near-infrared, multi-object spectrograph** proposed 
for the Nasmyth focus of GTC_. It will allow observers to obtain from **tens to hundreds of 
intermediate resolution spectra simultaneously**, in the nIR bands *Z, J, H* and  *K*. 
A multi-slit mask unit will be used for target acquisition. EMIR is designed 
to address the science goals of the proposing team and of the Spanish community at large.

PyEmir user guide: :ref:`user`

PyEmir reference guide: :ref:`reference`

.. toctree::
   :maxdepth: 1

   user/index 
   highlevel
   reference/index
   glossary

   
.. _GTC: http://www.gtc.iac.es
